ContainerReader

Struct ContainerReader 

pub struct ContainerReader<R: Read> { /* private fields */ }
Container reader that validates every field, bound, and hash.

Implementations

Source

impl<R: Read> ContainerReader<R>

pub fn new(reader: R, limits: Limits) -> Self

Create a new container reader.

pub fn read_header(&mut self) -> Result<FileHeader, AppError>

Read and validate the file header.

pub fn read_block<F>(&mut self, decode_fn: F) -> Result<Option<Block>, AppError>
where F: FnMut(&BlockHeaderInfo, &[u8], &[u8]) -> Result<Vec<u8>, AppError>,

Read and process the next block. Returns None when no more blocks (footer will be read separately).

Read and verify the footer.

pub fn check_trailing_data(&mut self) -> Result<(), AppError>

Check that there is no trailing data after the footer.