pub struct ContainerReader<R: Read> { /* private fields */ }Expand description
Container reader that validates every field, bound, and hash.
Implementations
Sourceimpl<R: Read> ContainerReader<R>
impl<R: Read> ContainerReader<R>
Sourcepub fn read_header(&mut self) -> Result<FileHeader, AppError>
pub fn read_header(&mut self) -> Result<FileHeader, AppError>
Read and validate the file header.
Sourcepub fn read_block<F>(&mut self, decode_fn: F) -> Result<Option<Block>, AppError>
pub fn read_block<F>(&mut self, decode_fn: F) -> Result<Option<Block>, AppError>
Read and process the next block. Returns None when no more blocks
(footer will be read separately).
Read and verify the footer.
Sourcepub fn check_trailing_data(&mut self) -> Result<(), AppError>
pub fn check_trailing_data(&mut self) -> Result<(), AppError>
Check that there is no trailing data after the footer.